Grid3

Struct Grid3 

pub struct Grid3<T = f32> { /* private fields */ }
Stores values on a 3D cube lattice on the coordinates [0,0,0] - [w-1, h-1, d-1]. A 3D tensor, basically.

TODO (nummelin): Should we separate storage so we can store just a bitset of inside/outside (which is enough for most uses).

Implementations

Source

impl<T> Grid3<T>

pub fn data(&self) -> &[T]

flat data

pub fn size(&self) -> Index3

Source

impl<T: SignedDistance + Copy + Clone + Default> Grid3<T>

pub fn new(size: Index3) -> Self

pub fn set(&mut self, f: impl FnMut(Index3) -> T)

Set the grid values using the given function.

Source

impl<T> Grid3<T>
where T: SignedDistance,

pub fn gradient_clamped(&self, p: Index3) -> Vec3

Returns the distance gradient at the given coordinate. Coordinate must be within the grid.

pub fn fast_gradient( &self, x: usize, y: usize, z: usize, i: usize, ys: usize, zs: usize, ) -> Vec3

Returns a fast approximation of the distance gradient at the given coordinate.

Coordinate must be within the grid.

pub fn set_truncated_sync( &mut self, sdf: impl Fn(Index3) -> T + Send + Sync, truncate_dist: f32, )

Will set all values closer than the given truncate distance

Cells outside the given truncate distance will have approximated distances.

Will run synchronously regardless of with_rayon feature availability.

pub fn set_truncated( &mut self, sdf: impl Fn(Index3) -> T + Send + Sync, truncate_dist: f32, )

Will set all values closer than the given truncate distance

Cells outside the given truncate distance will have approximated distances.

Source

impl<T> Grid3<T>
where T: SignedDistance,

pub fn marching_cubes_with_color( &self, color: impl Fn(Vec3) -> Vec3 + Send + Sync, ) -> TriangleMesh

Gives a mesh using colors from the given function

pub fn marching_cubes(&self) -> TriangleMesh

Does NOT return colors